==> sca-patterns-sle15-1.5.5.tar.gz: sca-patterns-sle15-1.5.5/patterns/SLE/sle15sp1/apache_SUSE-SU-2020_1126-1_15.1.py <==
#!/usr/bin/python3
#
# Title:       Important Security Announcement for Apache SUSE-SU-2020:1126-1
# Description: Security fixes for SUSE Linux Enterprise 15 SP1
# Source:      Security Announcement Parser v1.5.2
# Modified:    2020 Nov 16
#
##############################################################################
# Copyright (C) 2020 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record (jason.record@suse.com)
#
##############################################################################

import os
import Core
import SUSE

META_CLASS = "Security"
META_CATEGORY = "SLE"
META_COMPONENT = "Apache"
PATTERN_ID = os.path.basename(__file__)
PRIMARY_LINK = "META_LINK_Security"
OVERALL = Core.TEMP
OVERALL_INFO = "NOT SET"
OTHER_LINKS = "META_LINK_Security=https://lists.suse.com/pipermail/sle-security-updates/2020-April/006744.html"
Core.init(META_CLASS, META_CATEGORY, META_COMPONENT, PATTERN_ID, PRIMARY_LINK, OVERALL, OVERALL_INFO, OTHER_LINKS)

LTSS = False
NAME = 'Apache'
MAIN = ''
SEVERITY = 'Important'
TAG = 'SUSE-SU-2020:1126-1'
PACKAGES = {}
SERVER = SUSE.getHostInfo()

if ( SERVER['DistroVersion'] == 15):
	if ( SERVER['DistroPatchLevel'] == 1 ):
		PACKAGES = {
			'apache2': '2.4.33-3.30.1',
			'apache2-debuginfo': '2.4.33-3.30.1',
			'apache2-debugsource': '2.4.33-3.30.1',
			'apache2-devel': '2.4.33-3.30.1',
			'apache2-doc': '2.4.33-3.30.1',
			'apache2-event': '2.4.33-3.30.1',
			'apache2-event-debuginfo': '2.4.33-3.30.1',
			'apache2-example-pages': '2.4.33-3.30.1',
			'apache2-prefork': '2.4.33-3.30.1',
			'apache2-prefork-debuginfo': '2.4.33-3.30.1',
			'apache2-utils': '2.4.33-3.30.1',
			'apache2-utils-debuginfo': '2.4.33-3.30.1',
			'apache2-worker': '2.4.33-3.30.1',
			'apache2-worker-debuginfo': '2.4.33-3.30.1',
		}
		SUSE.securityAnnouncementPackageCheck(NAME, MAIN, LTSS, SEVERITY, TAG, PACKAGES)
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the service pack scope")
else:
	Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the distribution scope")
Core.printPatternResults()

==> sca-patterns-sle15-1.5.8.tar.gz: sca-patterns-sle15-1.5.8/patterns/SLE/sle15sp1/apache_SUSE-SU-2020_2344-1_15.1.py <==
#!/usr/bin/python3
#
# Title:       Moderate Security Announcement for Apache SUSE-SU-2020:2344-1
# Description: Security fixes for SUSE Linux Enterprise 15 SP1
# Source:      Security Announcement Parser v1.5.2
# Modified:    2020 Nov 16
#
##############################################################################
# Copyright (C) 2020 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record (jason.record@suse.com)
#
##############################################################################

import os
import Core
import SUSE

META_CLASS = "Security"
META_CATEGORY = "SLE"
META_COMPONENT = "Apache"
PATTERN_ID = os.path.basename(__file__)
PRIMARY_LINK = "META_LINK_Security"
OVERALL = Core.TEMP
OVERALL_INFO = "NOT SET"
OTHER_LINKS = "META_LINK_Security=https://lists.suse.com/pipermail/sle-security-updates/2020-August/007308.html"
Core.init(META_CLASS, META_CATEGORY, META_COMPONENT, PATTERN_ID, PRIMARY_LINK, OVERALL, OVERALL_INFO, OTHER_LINKS)

LTSS = False
NAME = 'Apache'
MAIN = ''
SEVERITY = 'Moderate'
TAG = 'SUSE-SU-2020:2344-1'
PACKAGES = {}
SERVER = SUSE.getHostInfo()

if ( SERVER['DistroVersion'] == 15):
	if ( SERVER['DistroPatchLevel'] == 1 ):
		PACKAGES = {
			'apache2': '2.4.33-3.33.1',
			'apache2-debuginfo': '2.4.33-3.33.1',
			'apache2-debugsource': '2.4.33-3.33.1',
			'apache2-devel': '2.4.33-3.33.1',
			'apache2-doc': '2.4.33-3.33.1',
			'apache2-prefork': '2.4.33-3.33.1',
			'apache2-prefork-debuginfo': '2.4.33-3.33.1',
			'apache2-utils': '2.4.33-3.33.1',
			'apache2-utils-debuginfo': '2.4.33-3.33.1',
			'apache2-worker': '2.4.33-3.33.1',
			'apache2-worker-debuginfo': '2.4.33-3.33.1',
		}
		SUSE.securityAnnouncementPackageCheck(NAME, MAIN, LTSS, SEVERITY, TAG, PACKAGES)
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the service pack scope")
else:
	Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the distribution scope")
Core.printPatternResults()
